import re
from typing import List, Optional

from intel_sgx_ra.quote import RE_CERT


def test_cert_regex():
    cert = """
-----BEGIN CERTIFICATE-----
MIIEbTCCA1WgAwIBAgISBGy4MdZMZpTp3KMVawsb9w8lMA0GCSqGSIb3DQEBCwUA
MDIxCzAJBgNVBAYTAlVTMRYwFAYDVQQKEw1MZXQncyBFbmNyeXB0MQswCQYDVQQD
EwJSMzAeFw0yMjA5MjgwOTA1MzZaFw0yMjEyMjcwOTA1MzVaMCQxIjAgBgNVBAMT
GW92aDIubWFjaGluZTEuY29zbWlhbi5jb20wWTATBgcqhkjOPQIBBggqhkjOPQMB
BwNCAASEjGWBjaCm7jEAe1WzQbytjx0up5Z7jKNGRvLi0oNp+EwRbrSbRrf/a6Wx
31khAAOu/8KcS/c79BHTboVK/hsWo4ICVDCCAlAwDgYDVR0PAQH/BAQDAgeAMB0G
A1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcDAjAMBgNVHRMBAf8EAjAAMB0GA1Ud
DgQWBBTDSYgq/p56i5kYZsybxAaQp6Y6CDAfBgNVHSMEGDAWgBQULrMXt1hWy65Q
CUDmH6+dixTCxjBVBggrBgEFBQcBAQRJMEcwIQYIKwYBBQUHMAGGFWh0dHA6Ly9y
My5vLmxlbmNyLm9yZzAiBggrBgEFBQcwAoYWaHR0cDovL3IzLmkubGVuY3Iub3Jn
LzAkBgNVHREEHTAbghlvdmgyLm1hY2hpbmUxLmNvc21pYW4uY29tMEwGA1UdIARF
MEMwCAYGZ4EMAQIBMDcGCysGAQQBgt8TAQEBMCgwJgYIKwYBBQUHAgEWGmh0dHA6
Ly9jcHMubGV0c2VuY3J5cHQub3JnMIIBBAYKKwYBBAHWeQIEAgSB9QSB8gDwAHYA
36Veq2iCTx9sre64X04+WurNohKkal6OOxLAIERcKnMAAAGDg48Y6wAABAMARzBF
AiAnE3IA5NKvfbkfTyijDvS6+08GBAaGBS9kBh82HmT9xQIhALnnJY2/FQWXy7RM
8OBoNCz3pfSfxZPJgdmuUhEpGBaCAHYARqVV63X6kSAwtaKJafTzfREsQXS+/Um4
havy/HD+bUcAAAGDg48ZDgAABAMARzBFAiBnrgNgi9GqstrtCHJh5VO4ALkbr5wi
vsf7orbevkrOzgIhAIQODOjVNqHMmYGx3OS1ttlHPkVKjeKKWJPzBLAhJsvgMA0G
CSqGSIb3DQEBCwUAA4IBAQBr4ET9exFAd9STfqqI9oDoKBtR+2npDj21Qtyi2gG8
q1a9/kYmXum84LDb41DWKbike7jbnXUUQXm1MmTa/qTZbAiACCqAlt2j5CXs1Tfw
9PhSrOoB/TT1Xx0g4mZq3+cWM6eNuFJAIhxWYxcXadvAoaVGzW6BVUt5E+cIRPeO
ElzX1JQ/759xtgP8s0nJ0UcIHT9uekp3Y9j8vazUquuxYJEvlhA28d7cdVz63zek
BhQCwo4lPG81Jsx0SoXbAWIWjKEiCKL+Q3iJLaTiATy8bvXai9NlFM7aP0CKu+bn
cfOKu2AMn1RHIGf+4AMm/nG+z+b9mpqm1zB9v10GED5Y
-----END CERTIFICATE-----""".encode("utf-8")

    m: Optional[re.Match] = re.search(RE_CERT, cert)
    assert m is not None

    only_one_cert: List[bytes] = re.findall(RE_CERT, cert)
    assert len(only_one_cert) == 1

    certs = """
-----BEGIN CERTIFICATE-----
MIIEbTCCA1WgAwIBAgISBGy4MdZMZpTp3KMVawsb9w8lMA0GCSqGSIb3DQEBCwUA
MDIxCzAJBgNVBAYTAlVTMRYwFAYDVQQKEw1MZXQncyBFbmNyeXB0MQswCQYDVQQD
EwJSMzAeFw0yMjA5MjgwOTA1MzZaFw0yMjEyMjcwOTA1MzVaMCQxIjAgBgNVBAMT
GW92aDIubWFjaGluZTEuY29zbWlhbi5jb20wWTATBgcqhkjOPQIBBggqhkjOPQMB
BwNCAASEjGWBjaCm7jEAe1WzQbytjx0up5Z7jKNGRvLi0oNp+EwRbrSbRrf/a6Wx
31khAAOu/8KcS/c79BHTboVK/hsWo4ICVDCCAlAwDgYDVR0PAQH/BAQDAgeAMB0G
A1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcDAjAMBgNVHRMBAf8EAjAAMB0GA1Ud
DgQWBBTDSYgq/p56i5kYZsybxAaQp6Y6CDAfBgNVHSMEGDAWgBQULrMXt1hWy65Q
CUDmH6+dixTCxjBVBggrBgEFBQcBAQRJMEcwIQYIKwYBBQUHMAGGFWh0dHA6Ly9y
My5vLmxlbmNyLm9yZzAiBggrBgEFBQcwAoYWaHR0cDovL3IzLmkubGVuY3Iub3Jn
LzAkBgNVHREEHTAbghlvdmgyLm1hY2hpbmUxLmNvc21pYW4uY29tMEwGA1UdIARF
MEMwCAYGZ4EMAQIBMDcGCysGAQQBgt8TAQEBMCgwJgYIKwYBBQUHAgEWGmh0dHA6
Ly9jcHMubGV0c2VuY3J5cHQub3JnMIIBBAYKKwYBBAHWeQIEAgSB9QSB8gDwAHYA
36Veq2iCTx9sre64X04+WurNohKkal6OOxLAIERcKnMAAAGDg48Y6wAABAMARzBF
AiAnE3IA5NKvfbkfTyijDvS6+08GBAaGBS9kBh82HmT9xQIhALnnJY2/FQWXy7RM
8OBoNCz3pfSfxZPJgdmuUhEpGBaCAHYARqVV63X6kSAwtaKJafTzfREsQXS+/Um4
havy/HD+bUcAAAGDg48ZDgAABAMARzBFAiBnrgNgi9GqstrtCHJh5VO4ALkbr5wi
vsf7orbevkrOzgIhAIQODOjVNqHMmYGx3OS1ttlHPkVKjeKKWJPzBLAhJsvgMA0G
CSqGSIb3DQEBCwUAA4IBAQBr4ET9exFAd9STfqqI9oDoKBtR+2npDj21Qtyi2gG8
q1a9/kYmXum84LDb41DWKbike7jbnXUUQXm1MmTa/qTZbAiACCqAlt2j5CXs1Tfw
9PhSrOoB/TT1Xx0g4mZq3+cWM6eNuFJAIhxWYxcXadvAoaVGzW6BVUt5E+cIRPeO
ElzX1JQ/759xtgP8s0nJ0UcIHT9uekp3Y9j8vazUquuxYJEvlhA28d7cdVz63zek
BhQCwo4lPG81Jsx0SoXbAWIWjKEiCKL+Q3iJLaTiATy8bvXai9NlFM7aP0CKu+bn
cfOKu2AMn1RHIGf+4AMm/nG+z+b9mpqm1zB9v10GED5Y
-----END CERTIFICATE-----

-----BEGIN CERTIFICATE-----
MIIFFjCCAv6gAwIBAgIRAJErCErPDBinU/bWLiWnX1owDQYJKoZIhvcNAQELBQAw
TzELMAkGA1UEBhMCVVMxKTAnBgNVBAoTIEludGVybmV0IFNlY3VyaXR5IFJlc2Vh
cmNoIEdyb3VwMRUwEwYDVQQDEwxJU1JHIFJvb3QgWDEwHhcNMjAwOTA0MDAwMDAw
WhcNMjUwOTE1MTYwMDAwWjAyMQswCQYDVQQGEwJVUzEWMBQGA1UEChMNTGV0J3Mg
RW5jcnlwdDELMAkGA1UEAxMCUjMwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEK
AoIBAQC7AhUozPaglNMPEuyNVZLD+ILxmaZ6QoinXSaqtSu5xUyxr45r+XXIo9cP
R5QUVTVXjJ6oojkZ9YI8QqlObvU7wy7bjcCwXPNZOOftz2nwWgsbvsCUJCWH+jdx
sxPnHKzhm+/b5DtFUkWWqcFTzjTIUu61ru2P3mBw4qVUq7ZtDpelQDRrK9O8Zutm
NHz6a4uPVymZ+DAXXbpyb/uBxa3Shlg9F8fnCbvxK/eG3MHacV3URuPMrSXBiLxg
Z3Vms/EY96Jc5lP/Ooi2R6X/ExjqmAl3P51T+c8B5fWmcBcUr2Ok/5mzk53cU6cG
/kiFHaFpriV1uxPMUgP17VGhi9sVAgMBAAGjggEIMIIBBDAOBgNVHQ8BAf8EBAMC
AYYwHQYDVR0lBBYwFAYIKwYBBQUHAwIGCCsGAQUFBwMBMBIGA1UdEwEB/wQIMAYB
Af8CAQAwHQYDVR0OBBYEFBQusxe3WFbLrlAJQOYfr52LFMLGMB8GA1UdIwQYMBaA
FHm0WeZ7tuXkAXOACIjIGlj26ZtuMDIGCCsGAQUFBwEBBCYwJDAiBggrBgEFBQcw
AoYWaHR0cDovL3gxLmkubGVuY3Iub3JnLzAnBgNVHR8EIDAeMBygGqAYhhZodHRw
Oi8veDEuYy5sZW5jci5vcmcvMCIGA1UdIAQbMBkwCAYGZ4EMAQIBMA0GCysGAQQB
gt8TAQEBMA0GCSqGSIb3DQEBCwUAA4ICAQCFyk5HPqP3hUSFvNVneLKYY611TR6W
PTNlclQtgaDqw+34IL9fzLdwALduO/ZelN7kIJ+m74uyA+eitRY8kc607TkC53wl
ikfmZW4/RvTZ8M6UK+5UzhK8jCdLuMGYL6KvzXGRSgi3yLgjewQtCPkIVz6D2QQz
CkcheAmCJ8MqyJu5zlzyZMjAvnnAT45tRAxekrsu94sQ4egdRCnbWSDtY7kh+BIm
lJNXoB1lBMEKIq4QDUOXoRgffuDghje1WrG9ML+Hbisq/yFOGwXD9RiX8F6sw6W4
avAuvDszue5L3sz85K+EC4Y/wFVDNvZo4TYXao6Z0f+lQKc0t8DQYzk1OXVu8rp2
yJMC6alLbBfODALZvYH7n7do1AZls4I9d1P4jnkDrQoxB3UqQ9hVl3LEKQ73xF1O
yK5GhDDX8oVfGKF5u+decIsH4YaTw7mP3GFxJSqv3+0lUFJoi5Lc5da149p90Ids
hCExroL1+7mryIkXPeFM5TgO9r0rvZaBFOvV2z0gp35Z0+L4WPlbuEjN/lxPFin+
HlUjr8gRsI3qfJOQFy/9rKIJR0Y/8Omwt/8oTWgy1mdeHmmjk7j1nYsvC9JSQ6Zv
MldlTTKB3zhThV1+XWYp6rjd5JW1zbVWEkLNxE7GJThEUG3szgBVGP7pSWTUTsqX
nLRbwHOoq7hHwg==
-----END CERTIFICATE-----

-----BEGIN CERTIFICATE-----
MIIFYDCCBEigAwIBAgIQQAF3ITfU6UK47naqPGQKtzANBgkqhkiG9w0BAQsFADA/
MSQwIgYDVQQKExtEaWdpdGFsIFNpZ25hdHVyZSBUcnVzdCBDby4xFzAVBgNVBAMT
DkRTVCBSb290IENBIFgzMB4XDTIxMDEyMDE5MTQwM1oXDTI0MDkzMDE4MTQwM1ow
TzELMAkGA1UEBhMCVVMxKTAnBgNVBAoTIEludGVybmV0IFNlY3VyaXR5IFJlc2Vh
cmNoIEdyb3VwMRUwEwYDVQQDEwxJU1JHIFJvb3QgWDEwggIiMA0GCSqGSIb3DQEB
AQUAA4ICDwAwggIKAoICAQCt6CRz9BQ385ueK1coHIe+3LffOJCMbjzmV6B493XC
ov71am72AE8o295ohmxEk7axY/0UEmu/H9LqMZshftEzPLpI9d1537O4/xLxIZpL
wYqGcWlKZmZsj348cL+tKSIG8+TA5oCu4kuPt5l+lAOf00eXfJlII1PoOK5PCm+D
LtFJV4yAdLbaL9A4jXsDcCEbdfIwPPqPrt3aY6vrFk/CjhFLfs8L6P+1dy70sntK
4EwSJQxwjQMpoOFTJOwT2e4ZvxCzSow/iaNhUd6shweU9GNx7C7ib1uYgeGJXDR5
bHbvO5BieebbpJovJsXQEOEO3tkQjhb7t/eo98flAgeYjzYIlefiN5YNNnWe+w5y
sR2bvAP5SQXYgd0FtCrWQemsAXaVCg/Y39W9Eh81LygXbNKYwagJZHduRze6zqxZ
Xmidf3LWicUGQSk+WT7dJvUkyRGnWqNMQB9GoZm1pzpRboY7nn1ypxIFeFntPlF4
FQsDj43QLwWyPntKHEtzBRL8xurgUBN8Q5N0s8p0544fAQjQMNRbcTa0B7rBMDBc
SLeCO5imfWCKoqMpgsy6vYMEG6KDA0Gh1gXxG8K28Kh8hjtGqEgqiNx2mna/H2ql
PRmP6zjzZN7IKw0KKP/32+IVQtQi0Cdd4Xn+GOdwiK1O5tmLOsbdJ1Fu/7xk9TND
TwIDAQABo4IBRjCCAUIwDwYDVR0TAQH/BAUwAwEB/zAOBgNVHQ8BAf8EBAMCAQYw
SwYIKwYBBQUHAQEEPzA9MDsGCCsGAQUFBzAChi9odHRwOi8vYXBwcy5pZGVudHJ1
c3QuY29tL3Jvb3RzL2RzdHJvb3RjYXgzLnA3YzAfBgNVHSMEGDAWgBTEp7Gkeyxx
+tvhS5B1/8QVYIWJEDBUBgNVHSAETTBLMAgGBmeBDAECATA/BgsrBgEEAYLfEwEB
ATAwMC4GCCsGAQUFBwIBFiJodHRwOi8vY3BzLnJvb3QteDEubGV0c2VuY3J5cHQu
b3JnMDwGA1UdHwQ1MDMwMaAvoC2GK2h0dHA6Ly9jcmwuaWRlbnRydXN0LmNvbS9E
U1RST09UQ0FYM0NSTC5jcmwwHQYDVR0OBBYEFHm0WeZ7tuXkAXOACIjIGlj26Ztu
MA0GCSqGSIb3DQEBCwUAA4IBAQAKcwBslm7/DlLQrt2M51oGrS+o44+/yQoDFVDC
5WxCu2+b9LRPwkSICHXM6webFGJueN7sJ7o5XPWioW5WlHAQU7G75K/QosMrAdSW
9MUgNTP52GE24HGNtLi1qoJFlcDyqSMo59ahy2cI2qBDLKobkx/J3vWraV0T9VuG
WCLKTVXkcGdtwlfFRjlBz4pYg1htmf5X6DYO8A4jqv2Il9DjXA6USbW1FzXSLr9O
he8Y4IWS6wY7bCkjCWDcRQJMEhg76fsO3txE+FiYruq9RUWhiF1myv4Q6W+CyBFC
Dfvp7OOGAN6dEOM4+qR9sdjoSYKEBpsr6GtPAQw4dy753ec5
-----END CERTIFICATE-----""".encode("utf-8")

    multiple_cert: List[bytes] = re.findall(RE_CERT, certs)
    assert len(multiple_cert) == 3
